# ParticlePhaseSpace

![tests](https://github.com/bwheelz36/ParticlePhaseSpace/actions/workflows/run_tests.yml/badge.svg)![tests](https://github.com/bwheelz36/ParticlePhaseSpace/actions/workflows/build_docs.yml/badge.svg)[![codecov](https://codecov.io/gh/bwheelz36/ParticlePhaseSpace/branch/main/graph/badge.svg?token=T44KBJ7INR)](https://codecov.io/gh/bwheelz36/ParticlePhaseSpace)[![PyPI version](https://badge.fury.io/py/ParticlePhaseSpace.svg)](https://badge.fury.io/py/ParticlePhaseSpace)

Common library for dealing with particle phase spaces. This library supports the read in, analysis, and export of particle phase space data with extesnible support for different unit sets.
It also provides an extensible mechanisms for the import and export of phase space data in different formats.

## Install and Requirements

To install: ```pip install ParticlePhaseSpace```

## Usage and Documentation

Detailed documentation is provided [here](https://bwheelz36.github.io/ParticlePhaseSpace/).

The source code for the [worked examples](https://bwheelz36.github.io/ParticlePhaseSpace/examples.html) is inside the examples folder.

## Directory Structure

- **ParticlePhaseSpaace:** source code
- **examples:** source code for the [worked examples](https://bwheelz36.github.io/ParticlePhaseSpace/examples.html) provided in the docs
- **docsrc:** markdown/rst documentation.
- **tests:** tests which are run through github actions

## Other packages for analysis of particle phase space data

Below is a (almost certainly incomplete) list of other packages I have come accross for analysis of particle phase space data:

- [p2sat](https://github.com/lesnat/p2sat)
- [postpic](https://github.com/skuschel/postpic)
